哪吒闹海 (豆瓣)
Description: 哪吒闹海电影简介和剧情介绍,哪吒闹海影评、图片、预告片、影讯、论坛、在线购票
Keywords: 哪吒闹海,哪吒闹海,哪吒闹海影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.148豆瓣电影Top250

# 哪吒闹海 (1979)

导演: 王树忱 / 严定宪 / 徐景达
编剧: 王树忱
主演: 梁正晖 / 邱岳峰 / 毕克 / 富润生 / 尚华 / 于鼎
类型: 动画 / 奇幻 / 冒险
制片国家/地区: 中国大陆
语言: 汉语普通话
上映日期: 1979-05-19(中国大陆)
片长: 65分钟
又名: Prince Nezha's Triumph Against Dragon King / Nezha Conquers the Dragon King
IMDb: tt0354770
豆瓣评分
引用
9.2
244103人评价
5星
64.9%
4星
28.3%
3星
6.3%
2星
0.4%
1星
0.1%
好于 98% 动画片
好于 98% 冒险片
想看 看过
评价:
推荐

## 哪吒闹海的剧情简介 · · · · · ·

商末时期，陈塘关总兵李靖的夫人怀胎3年6个月，最终生下一个肉球，肉球中跳出一个伶俐可爱的男孩。李靖原当他是妖孽欲杀之而后快，幸太乙真人前来收之为徒，赐名哪吒，并赐以乾坤圈和混天绫两件宝贝。某年，天下大旱，甘露未降。哪吒和家将到东海洗澡玩耍。他用混天绫搅动海水，撼动龙宫，惹出巡海夜叉李艮和龙王三太子敖丙。几番言语不和，哪吒杀此二人，由此闯下通天大祸。四海龙王齐聚陈塘关索命，为救一方百姓，哪吒决定交出生命……
本片根据《封神演义》故事改编，并荣获1980年电影百花奖最佳美术片奖；文化部1979年优秀影片奖、青年优秀创作奖；1983年菲律宾马尼拉国际电影节特别奖；1988年法国布尔波拉斯文化俱乐部青年国际动画电影节评委奖和宽银幕长动画片奖。 ©豆瓣

## 哪吒闹海的演职员 · · · · · · ( 全部 35 )

- 王树忱 导演
- 严定宪 导演
- 梁正晖 配音
- 邱岳峰 配音
- 毕克 配音
- 富润生 配音

## 哪吒闹海的图片 · · · · · · ( 添加视频评论 | 图片545 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  大闹天宫

  天书奇谭

  三个和尚

  九色鹿

  小蝌蚪找妈妈

  雪孩子

  神笔

  天空之城

  幽灵公主

  没头脑和不高兴

我要写短评

## 哪吒闹海的短评 · · · · · · ( 全部 33300 条 )

热门 / 最新 / 好友

### 2100 有用 丁一 看过 2010-06-08 11:55:26

～想你时～你在闹海～

### 2153 有用 冰山的阴影 看过 2013-07-25 15:47:49

蒋勋在孤独六讲里写哪吒，他说，我记得年少时，读到哪吒把肉身还给父母，变成幽魂，最后找了与父母不相干的东西作为肉体的寄托，隐约感觉到那是当时的我最想做的背叛，我不希望有血缘，血缘是我巨大的负担和束缚。父母是我们最大的原罪，是一辈子还不了的亏欠，就是欠他骨肉，欠他血脉，所以当小说描述到哪吒削骨还父，割肉还母时，会给读者带来那么大的震撼。可是，这个角色在过去饱受争议，大家不敢讨论他，因为在百善孝为先的前... 蒋勋在孤独六讲里写哪吒，他说，我记得年少时，读到哪吒把肉身还给父母，变成幽魂，最后找了与父母不相干的东西作为肉体的寄托，隐约感觉到那是当时的我最想做的背叛，我不希望有血缘，血缘是我巨大的负担和束缚。父母是我们最大的原罪，是一辈子还不了的亏欠，就是欠他骨肉，欠他血脉，所以当小说描述到哪吒削骨还父，割肉还母时，会给读者带来那么大的震撼。可是，这个角色在过去饱受争议，大家不敢讨论他，因为在百善孝为先的前提之下，他是一个孤独的出走者。 (展开)

### 1475 有用 朝暮雪 看过 2012-08-18 13:58:15

哪吒刚刚降生，李靖就想一剑劈了他； 龙王恶人先告状，李靖却丝毫不听哪吒的解释； 哪吒制服了龙王，李靖又叫人把他绑起来； 面对四海龙王的报复，他甚至想杀死哪吒…… 是怎样的父亲，才会对自己的亲生骨肉心存偏见？ 是怎样的父亲，才会胳膊往外拐，站在别人那边？ 是怎样的父亲，才会是非颠倒，不分青红皂白？ 并非所有的孩子都是熊孩子，反而是很多父母不配做父母。 在这个“百善孝为先”的国度，《哪吒闹海》没有跟风... 哪吒刚刚降生，李靖就想一剑劈了他； 龙王恶人先告状，李靖却丝毫不听哪吒的解释； 哪吒制服了龙王，李靖又叫人把他绑起来； 面对四海龙王的报复，他甚至想杀死哪吒…… 是怎样的父亲，才会对自己的亲生骨肉心存偏见？ 是怎样的父亲，才会胳膊往外拐，站在别人那边？ 是怎样的父亲，才会是非颠倒，不分青红皂白？ 并非所有的孩子都是熊孩子，反而是很多父母不配做父母。 在这个“百善孝为先”的国度，《哪吒闹海》没有跟风歌颂父母，反而敢于质疑权威，提出了“是否所有父母都称职”的疑问，其深度和前瞻性都是国漫中的佼佼者。 哪吒那句“爹爹，你的骨肉我还给你，我不连累你”更为震撼。 你不认可我，我不强求。 你选择了懦弱，我选择承担。 舍身取义，以死明志，宁为玉碎，不为瓦全。 40年过去了没看过更震撼的国漫。 (展开)

### 1428 有用 柳具足 看过 2007-02-23 16:45:40

哪吒要是搁现在，就是一少儿精神病患者：躁郁症、暴力狂、自杀倾向、逆反心理……辅导人员要密切关注他看什么书，听什么音乐，玩什么电脑游戏，业余时间从事什么活动，必须定期参加心理辅导，服用抗躁郁症药……比美国哥伦比亚中学枪击案主谋更犀利的家伙

### 529 有用 亵渎电影 看过 2019-07-21 12:00:12

电影真的是时代的产物，小时候看这版的哪吒，不觉得故事有问题，现在再看，才发现这是一个政治味道浓重的故事，传达的价值观念赤裸裸。对比饺子导演对【哪吒之魔童降世】的处理，我命由我不由天的主题又很符合我们当下的主流价值观，哪吒变成了另外一个故事，可能会成为现在这代小朋友的童年回忆，和我们这一代看的哪吒是完全不一样的，可能这就是讲故事的魅力吧。

> 更多短评 33300条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 哪吒闹海的影评 · · · · · · ( 全部 236 条 )

热门 / 最新 / 好友
观影报告 2019-07-22 03:01:53

## 1979年的《哪吒闹海》为何是最伟大的哪吒？

这篇影评可能有剧透

又看了一遍1979年的《哪吒闹海》，又一次热泪盈眶。人老了，越容易被人世间的真情打动，年轻时反而麻木，误以为那是坚强。 哪吒形象自古就有，到了明代，许仲琳写了《封神演义》，哪吒的形象于文献中清晰起来。令人震惊的是，我大学时读到《封神演义》中的哪吒根本就是一个睚眦... (展开)
912 5 93回应 收起
老晃 2005-09-04 12:57:31

## 腰斩[哪吒闹海]

傀儡与神灵 ——腰斩[哪吒闹海] 导 演：王树忱、严定宪、阿达 编 剧：王往 出 品：上海美术电影制片厂，1979 片 长： 59分钟 一切神灵都曾遭到阉割，所以，他们实际上都是傀儡。 　　[哪吒闹海]是一个鲜血淋漓的故事，讲述的是中国传统文化中阉割和... (展开)
466 72 102回应 收起
汤舸 2009-07-10 11:58:18

## 那剑刃上倒映出的凄厉眼神

哪吒的故事是一个只有恨的冷酷故事。 对父亲的恨，对兄弟的恨，对母亲的恨，对儿子的恨，对仇雠的恨，对天地不仁的恨，对造物弄人的恨。对敌人是恨，对亲人更是恨。这恨引起滔滔洪水灌取陈塘关，这恨如剔骨尖刀剥去层层血肉，这恨更加如一道悬崖般隔开亲情伦理与教化，使得世界... (展开)
233 14 23回应 收起
けせん 2020-02-14 05:04:04

## 作为陈塘关的百姓说两句

这篇影评可能有剧透

哪吒抽龙太子龙筋。你作为陈塘关百姓你生什么气，你又不是龙族？龙王胡作非为你不生气，哪吒替你声张正义你还骂哪吒。你大概怕龙王迁怒于百姓发洪水报复陈塘关？甚至李靖自己也这么想。 你要知道，不管哪吒抽不抽龙筋，龙王想发洪水就发洪水。你不贡三牲发洪水，你不送童男童女... (展开)
95 1 12回应 收起
厄庇墨透斯 2006-10-15 20:53:34

## 哪吒，我性感的小英雄

8月23日，中午无意间翻到少儿台，历历在播《哪吒闹海》，立刻跟着重温。 话说哪吒去东海消闲耍子也有7岁了，可倒脱得凉快，只一件兜肚，勉强遮挡小腹罢了，臂膀上缠了胎里带的混天绫，颈项上套着金灿灿的乾坤圈……我年纪大了，看什么都有不良想法，这童子的打扮哪，真... (展开)
57 15 31回应 收起
南玖 2017-05-11 23:52:15

## 想你时你在天边

这篇影评可能有剧透

有诗曰: 金光洞里有奇珍，降落尘寰辅至仁。 周室已生佳气色；商家应自灭精神。 从来泰运多梁栋，自古昌期有幼燐。 戊午时中逢甲子，慢嗟朝野尽沉沦。 哪吒出生的场面就给了他一个传奇的开端，但传奇的成就却是因为他的自刎，与重生。这里先把重点放在重生之前，出生的异常给李... (展开)
27 0回应 收起
雪 2017-06-13 12:46:15

## 莫名的快意

国产动画中的经典之作。 看过许多遍，尤其记得哪吒被逼自杀时，剔骨还父，说，我不连累你，我还给你。每次看到这里，总有种莫名的快意，不知为了什么。是一种反社会压制反伦理重担的宣泄吗？ 李靖这人物塑造得面目可憎，是个胆小怯懦，无情无义的封建体制下大家长的形... (展开)
40 2 0回应 收起
阿风 2008-08-30 10:11:26

## 中国动画电影巅峰之作

1979年出品的《哪咤闹海》似乎标志着中国动画巅峰时代的真正结束。在进入八十年代以后，中国动画虽然出现诸多具有探索性的作品，如《三个和尚》、《山水情》、《漠风》等，但是它们的星星之火最终没有燎原，中国动画在挣扎中还是宿命般地走向了衰微、沉寂。 　　 同《大闹天宫... (展开)
37 2 8回应 收起
余小岛 2019-07-26 14:31:44

## 当代朋克哪吒

又看了一遍哪吒。 片子不长，从哪吒怀胎三年零六个月出生，到剔骨还父、割肉还母，自刎死去，再到莲花重生、大闹东海，65分钟而已。可是这短短的65分钟，却是字字珠玑，每一分钟都是雷霆万分。 以前说过，《哪吒闹海》可能是我看过的第一部电影。小时候，家里买了第一台影碟机... (展开)
32 3回应 收起
小怪兽的凝视 2017-03-26 17:50:05

## 哪吒闹海

影片开头便著名“根据《封神演义》片段改编”，恰好《封神演义》我是看过的，那就先说说与原著的异同吧。影片的前半段是基本忠实原著的，所不同的是一些细节的描写，但正是这些细节之处的画龙点睛，使整部片子的立意与原著完全不同。原著中闹海是由于哪吒的年幼无知引发的偶然... (展开)
22 0回应 收起

> 更多影评 236篇

添加新讨论

## 讨论区 · · · · · ·

这豆瓣标的咋是65分钟？ | 来自盖世莫 | 7 回应 | 2022-11-19 11:11:42
本来中国动漫是日本动漫的学习对象！！ | 来自豆友gFlhhS8Wjo | 1 回应 | 2022-11-19 11:04:36
适合小孩子看吗？ | 来自Uni-verse | 2 回应 | 2022-11-04 04:31:47
新老哪吒对比，还是老哪吒能让人坐的住 | 来自李无忧 | 20 回应 | 2022-09-21 14:59:48
我的童年 | 来自艾艾 | 1 回应 | 2022-09-03 12:34:10

> 去这部影片的讨论区（全部85条）

## 关于《哪吒闹海》的问题 · · · · · · ( 全部2个 )

- 片长？？？？？？？？ 2人回答
- 为什么有风火轮走路还要迈步？ 5人回答

> 全部2个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 优酷视频 免费观看
- 1905电影网 免费观看
- 哔哩哔哩 免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- 80末出生的人是这样成长的 (沉歌)
- 【爱看动画】 (影志)
- 中文电影250强总榜（1905——2012） (东方快车)
- 《看电影》杂志中文电影100强 (东方快车)

## 谁在看这部电影 · · · · · ·

- 戒
  刚刚 看过
- Cloris雷菁
  3分钟前 看过
- 不知名选手Du
  12分钟前 看过

441627人看过 / 75655人想看

订阅哪吒闹海的评论:
feed: rss 2.0